==> haskell-sendfile-0.7.11.6-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sendfile
version:              0.7.11.6
visibility:           public
id:                   sendfile-0.7.11.6-DZVFQQ30qE2IPxL7D74JDW
key:                  sendfile-0.7.11.6-DZVFQQ30qE2IPxL7D74JDW
license:              BSD-3-Clause
maintainer:           Jeremy Shaw <jeremy@n-heptane.com>
author:               Matthew Elder <matt@mattelder.org>
stability:            provisional
homepage:             https://github.com/Happstack/sendfile
synopsis:             A portable sendfile library
description:
    A library which exposes zero-copy sendfile functionality in a portable way. If a platform does not support sendfile, a fallback implementation in haskell is provided.

    Currently supported platforms: Windows 2000+ (Native), Linux 2.6+ (Native), FreeBSD (Native), OS-X 10.5+ (Native), Everything else (Portable Haskell code).

category:             Network
abi:                  ee23000a89de2ed90535fe6cce94054e
exposed:              True
exposed-modules:
    Network.Socket.SendFile Network.Socket.SendFile.Handle
    Network.Socket.SendFile.Iter Network.Socket.SendFile.Portable

hidden-modules:
    Network.Socket.SendFile.Internal Network.Socket.SendFile.Util
    Network.Socket.SendFile.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sendfile-0.7.11.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sendfile-0.7.11.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sendfile-0.7.11.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sendfile
hs-libraries:         HSsendfile-0.7.11.6-DZVFQQ30qE2IPxL7D74JDW
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-F6j0uAI5udHBrXI4nYArv7

haddock-interfaces:   /usr/share/doc/haskell-sendfile/html/sendfile.haddock
haddock-html:         /usr/share/doc/haskell-sendfile/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sendfile-0.7.11.6-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sendfile
version:              0.7.11.6
visibility:           public
id:                   sendfile-0.7.11.6-151Ts8yuoYqK2rOSYdyer9
key:                  sendfile-0.7.11.6-151Ts8yuoYqK2rOSYdyer9
license:              BSD-3-Clause
maintainer:           Jeremy Shaw <jeremy@n-heptane.com>
author:               Matthew Elder <matt@mattelder.org>
stability:            provisional
homepage:             https://github.com/Happstack/sendfile
synopsis:             A portable sendfile library
description:
    A library which exposes zero-copy sendfile functionality in a portable way. If a platform does not support sendfile, a fallback implementation in haskell is provided.

    Currently supported platforms: Windows 2000+ (Native), Linux 2.6+ (Native), FreeBSD (Native), OS-X 10.5+ (Native), Everything else (Portable Haskell code).

category:             Network
abi:                  4c5682afd27201d5bb57065792c24d2f
exposed:              True
exposed-modules:
    Network.Socket.SendFile Network.Socket.SendFile.Handle
    Network.Socket.SendFile.Iter Network.Socket.SendFile.Portable

hidden-modules:
    Network.Socket.SendFile.Internal Network.Socket.SendFile.Util
    Network.Socket.SendFile.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sendfile-0.7.11.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sendfile-0.7.11.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sendfile-0.7.11.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sendfile
hs-libraries:         HSsendfile-0.7.11.6-151Ts8yuoYqK2rOSYdyer9
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-KV3OkCyx0pcI1DdyD3ZbeB

haddock-interfaces:   /usr/share/doc/haskell-sendfile/html/sendfile.haddock
haddock-html:         /usr/share/doc/haskell-sendfile/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
